@@ -15,7 +15,7 @@ class Formatter(dict):
     def __missing__(self, key):
         if key == "time":
             return datetime.now().strftime(self.time_format)
-        elif key == "time":
+        elif key == "date":
             return datetime.now().strftime(self.date_format)
         elif key.startswith("#"):
             if key == "#reset":
@@ -80,7 +80,8 @@ def cstm(pattern, **kwargs):
     sys.stdout.write(
         ACC.RESET + pattern.format_map(Formatter(**kwargs)) + ACC.RESET + "\n"
     )
-
+def smart_format(pattern, **kwargs):
+    return pattern.format_map(Formatter(**kwargs))
 
 def init_from_cfg():
     default_config = {
