@@ -54,21 +54,27 @@ def parse_args(readed):
     # [\"][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,\'-/]+
     # [\"][a-zA-ZА-ЯЁа-яё‘\d\s[\]{}()@#_=%?\*\\\.:;,\'-/]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d\.[\]{}()@\\\.:;,\'-/]+
     # [\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–]+
-    # [\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+ (NOW)
+    # [\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+
+    # \"[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\s]*\"|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+
 
     """
     Args:
         readed:
     """
+
     res = re.findall(
-        r"[\"][a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\d]*[\"]|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+",
+        r"\"[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()<>@\\:;,\'\-\/!?#$%^&*_+в„–\s]*\"|[a-zA-ZA-ZА-ЯЁа-яё‘\d.[\]{}()@\\:;,\'\-\/!?#$%^&*_+в„–<>]+",
         readed,
         re.MULTILINE,
     )
     res2 = []
     for item in res:
-        res2.append(re.sub(r"\B'|\b'", "", item))
+        if item.startswith('"'):
+            res2.append(item[1:-1])
+        else:
+            res2.append(item)
     res = [x for x in res2 if x != ""]
+
     if len(res) == 0:
         return {"command": "", "param": [], "paramCount": 0, "split": []}
     if len(res) == 1:
