@@ -2,42 +2,9 @@ import inspect
 import random
 import re
 
-from NewLifeUtils.LoggerModule import *
+
 from NewLifeUtils.StringUtilModule import parse_args
 
-
-def select_rand_list(source, use_zero=False):
-    try:
-        source[0]
-    except IndexError:
-        err(f"{source} is empty", "RS ERROR")
-    except TypeError:
-        err(f"{source} object is not subscriptable", "RS ERROR")
-    else:
-        if use_zero:
-            log("Can use zero", "RS LOG")
-            selector = random.randrange(1, len(source))
-        else:
-            log("Cant use zero", "RS LOG")
-            selector = random.randrange(0, len(source))
-        log(
-            f"Select item #{selector} from {type(source).__name__}; result {source[selector]}",
-            "RS LOG",
-        )
-        return source[selector]
-    return None
-
-
-def getfromfname(a):
-    res = ""
-    for e in inspect.stack():
-        try:
-            res += e.code_context[0]
-        except Exception:
-            res += " <Unknown>"
-    return res.rstrip("\n").rsplit("\n", 1)[-1]
-
-
 def __partition(nums, low, high):
     # Выбираем средний элемент в качестве опорного
     # Также возможен выбор первого, последнего
@@ -74,41 +41,9 @@ def quick_sort(nums):
     _quick_sort(nums, 0, len(nums) - 1)
 
 
-def bprint(text, maxlinelength=9, font="default"):
-    print(get_files_from_dir("fonts"))
 
 
-def format_number(
-    number=random.randrange(1111111111111111, 9999999999999999),
-    numform="4444",
-):
-    # A total conversion
-    number = int(number)
-    numform = str(numform)
-    # Total length
-    total_length = 0
-    for num in numform:
-        total_length += int(num)
-
-    # Dividing or lengthening a number
-    if number == 0:
-        number = 1
-
-    if len(str(number)) < total_length:
-        while len(str(number)) < total_length:
-            number = number * 10
-    elif len(str(number)) > total_length:
-        number = int(str(number)[0:total_length])
-
-    # Add spaces
-    result = str(number)
-    shift = 0
-    for pos in numform:
-        result = result[: int(pos) + shift] + " " + result[int(pos) + shift :]
-        shift += int(pos) + 1
-    return result
-
-def safe_format(text, keys=None, func = None, smart=None):
+def safe_format(text, keys=None, func=None, smart=None):
     if keys is None:
         keys = {}
     if smart is None:
@@ -119,11 +54,11 @@ def safe_format(text, keys=None, func = None, smart=None):
             nonlocal func
             if smart is not {}:
                 keypr = parse_args(key)
-                name = keypr['command']
+                name = keypr["command"]
                 if name not in smart.keys():
                     return "{" + key + "}"
                 else:
-                    return smart[name](*keypr['param'])
+                    return smart[name](*keypr["param"])
             elif func is not None:
                 return "{" + str(func(key)) + "}"
             else:
@@ -132,14 +67,6 @@ def safe_format(text, keys=None, func = None, smart=None):
     return text.format_map(SafeDict(**keys))
 
 
-def set_seed_formated(seed=-1):
-    if seed == -1:
-        seed = format_number()
-    processed_seed = int("".join(seed.split()))
-    random.seed = processed_seed
-    return processed_seed
-
-
 def hex_to_rgb(hx, hsl=False):
     """Converts a HEX code into RGB or HSL.
     Args:
@@ -161,3 +88,18 @@ def hex_to_rgb(hx, hsl=False):
             for i in (1, 3, 5)
         )
     raise ValueError(f'"{hx}" is not a valid HEX code.')
+
+
+def remove_emoji(string):
+    emoji_pattern = re.compile(
+        "["
+        "\U0001F600-\U0001F64F"  # emoticons
+        "\U0001F300-\U0001F5FF"  # symbols & pictographs
+        "\U0001F680-\U0001F6FF"  # transport & map symbols
+        "\U0001F1E0-\U0001F1FF"  # flags (iOS)
+        "\U00002702-\U000027B0"
+        "\U000024C2-\U0001F251"
+        "]+",
+        flags=re.UNICODE,
+    )
+    return emoji_pattern.sub(r"", string)
